import { world, system } from "@minecraft/server";

world.afterEvents.itemUse.subscribe((event) => {
    const { itemStack, source } = event
    if (itemStack.typeId == "sl_oc:jelly_fish_bow") {
        shootProjectile(source, "sl_oc:arrow", 2)
    }
})

world.afterEvents.entityHitEntity.subscribe((event) => {
    const { damagingEntity, hitEntity } = event
    const itemInHand = damagingEntity?.getComponent("equippable")?.getEquipment("Mainhand")?.typeId;
    if (damagingEntity.typeId == "minecraft:player" && itemInHand == "sl_oc:fishsword") {
        hitEntity.applyDamage(6)
    }
})

world.afterEvents.entityHurt.subscribe((event) => {
    const { damage, damageSource, hurtEntity } = event
    if (hurtEntity.typeId == "minecraft:player") {
        if (hurtEntity.hasTag("crabArmor")) {
            damageSource.damagingEntity.applyDamage(6)
        }
    }
})

system.runInterval(() => {
    const players = world.getAllPlayers()
    for (let player of players) {
        if (!player.hasTag("sl_oc:start")) {
            player.runCommand("give @s sl_oc:npc_spawn_egg")
            player.addTag("sl_oc:start")
        }
        player.runCommand("function slovet/ocean/main")
        player.runCommand("function slovet/ocean/submarine")
        player.runCommand("function slovet/ocean/shark")
        const isRiding = player.getComponent("riding")

        if (isRiding) {
            if (player.isJumping) {
                player.addTag("submarineDown")
                player.addTag("submarineRide")
            } else {
                player.removeTag("submarineDown")
            }
            player.addTag("slovetPirate")
        } else {
            player.removeTag("slovetPirate")
            player.removeTag("boatPlayer")
            player.removeTag("submarineDown")
            player.removeTag("submarineRide")
        }

        if (player.hasTag("sharkArmor")) {
            if (player.isInWater) {
                if(player.isJumping){
                    player.applyKnockback(
                        player.getViewDirection().x,
                        player.getViewDirection().z,
                        1,
                        player.getViewDirection().y / 2
                    )
                }
            }
        }

        const itemInHand = player.getComponent("equippable").getEquipment("Mainhand")?.typeId;
        if (itemInHand?.startsWith("sl_oc:") && (itemInHand?.endsWith("_boots") || itemInHand?.endsWith("_chestplate") || itemInHand?.endsWith("_helmet") || itemInHand?.endsWith("_leggings"))) {
            player.playAnimation("animation.sl_oc.size.icon")
        }
    }
}, 1)

function shootProjectile(source, projectile, velocity) {
    const { x: pX, y: pY, z: pZ } = source.location;
    const { x: vX, y: vY, z: vZ } = source.getViewDirection();
    const { x: rX, y: rY } = source.getRotation();
    const dimension = source.dimension
    if (source.getViewDirection().y > 0.5) {
        const bullet = dimension.spawnEntity(projectile, {
            x: pX + vX,
            y: pY + vY + 3,
            z: pZ + vZ,
        });
        const buls = velocity;
        bullet.setRotation({
            x: rX,
            y: rY,
        });
        bullet.applyImpulse({
            x: vX * buls,
            y: vY * buls,
            z: vZ * buls,
        });
    } else {
        const bullet = dimension.spawnEntity(projectile, {
            x: pX + vX,
            y: pY + 1,
            z: pZ + vZ,
        });
        const buls = velocity;
        bullet.setRotation({
            x: rX,
            y: rY,
        });
        bullet.applyImpulse({
            x: vX * buls,
            y: vY * buls,
            z: vZ * buls,
        });
    }
}